#include <1.5/dom/domConstants.h>

namespace ColladaDOM150 {

DLLSPEC daeString COLLADA_VERSION = "1.5.0";
DLLSPEC daeString COLLADA_NAMESPACE = "http://www.collada.org/2008/03/COLLADASchema";

DLLSPEC daeString COMMON_PROFILE_INPUT_BINORMAL = "BINORMAL";
DLLSPEC daeString COMMON_PROFILE_INPUT_COLOR = "COLOR";
DLLSPEC daeString COMMON_PROFILE_INPUT_CONTINUITY = "CONTINUITY";
DLLSPEC daeString COMMON_PROFILE_INPUT_IMAGE = "IMAGE";
DLLSPEC daeString COMMON_PROFILE_INPUT_IN_TANGENT = "IN_TANGENT";
DLLSPEC daeString COMMON_PROFILE_INPUT_INPUT = "INPUT";
DLLSPEC daeString COMMON_PROFILE_INPUT_INTERPOLATION = "INTERPOLATION";
DLLSPEC daeString COMMON_PROFILE_INPUT_INV_BIND_MATRIX = "INV_BIND_MATRIX";
DLLSPEC daeString COMMON_PROFILE_INPUT_JOINT = "JOINT";
DLLSPEC daeString COMMON_PROFILE_INPUT_LINEAR_STEPS = "LINEAR_STEPS";
DLLSPEC daeString COMMON_PROFILE_INPUT_MORPH_TARGET = "MORPH_TARGET";
DLLSPEC daeString COMMON_PROFILE_INPUT_MORPH_WEIGHT = "MORPH_WEIGHT";
DLLSPEC daeString COMMON_PROFILE_INPUT_NORMAL = "NORMAL";
DLLSPEC daeString COMMON_PROFILE_INPUT_OUTPUT = "OUTPUT";
DLLSPEC daeString COMMON_PROFILE_INPUT_OUT_TANGENT = "OUT_TANGENT";
DLLSPEC daeString COMMON_PROFILE_INPUT_POSITION = "POSITION";
DLLSPEC daeString COMMON_PROFILE_INPUT_TANGENT = "TANGENT";
DLLSPEC daeString COMMON_PROFILE_INPUT_TEXBINORMAL = "TEXBINORMAL";
DLLSPEC daeString COMMON_PROFILE_INPUT_TEXCOORD = "TEXCOORD";
DLLSPEC daeString COMMON_PROFILE_INPUT_TEXTANGENT = "TEXTANGENT";
DLLSPEC daeString COMMON_PROFILE_INPUT_UV = "UV";
DLLSPEC daeString COMMON_PROFILE_INPUT_VERTEX = "VERTEX";
DLLSPEC daeString COMMON_PROFILE_INPUT_WEIGHT = "WEIGHT";

DLLSPEC daeString COMMON_PROFILE_PARAM_A = "A";
DLLSPEC daeString COMMON_PROFILE_PARAM_ANGLE = "ANGLE";
DLLSPEC daeString COMMON_PROFILE_PARAM_B = "B";
DLLSPEC daeString COMMON_PROFILE_PARAM_DOUBLE_SIDED = "DOUBLE_SIDED";
DLLSPEC daeString COMMON_PROFILE_PARAM_G = "G";
DLLSPEC daeString COMMON_PROFILE_PARAM_P = "P";
DLLSPEC daeString COMMON_PROFILE_PARAM_Q = "Q";
DLLSPEC daeString COMMON_PROFILE_PARAM_R = "R";
DLLSPEC daeString COMMON_PROFILE_PARAM_S = "S";
DLLSPEC daeString COMMON_PROFILE_PARAM_T = "T";
DLLSPEC daeString COMMON_PROFILE_PARAM_TIME = "TIME";
DLLSPEC daeString COMMON_PROFILE_PARAM_U = "U";
DLLSPEC daeString COMMON_PROFILE_PARAM_V = "V";
DLLSPEC daeString COMMON_PROFILE_PARAM_W = "W";
DLLSPEC daeString COMMON_PROFILE_PARAM_X = "X";
DLLSPEC daeString COMMON_PROFILE_PARAM_Y = "Y";
DLLSPEC daeString COMMON_PROFILE_PARAM_Z = "Z";


DLLSPEC daeString COLLADA_TYPE_INPUT_GLOBAL = "input_global";
DLLSPEC daeString COLLADA_TYPE_INPUT_LOCAL = "input_local";
DLLSPEC daeString COLLADA_TYPE_INPUT_LOCAL_OFFSET = "input_local_offset";
DLLSPEC daeString COLLADA_TYPE_TARGETABLE_FLOAT = "targetable_float";
DLLSPEC daeString COLLADA_TYPE_TARGETABLE_FLOAT3 = "targetable_float3";
DLLSPEC daeString COLLADA_TYPE_TOKEN_ARRAY = "token_array";
DLLSPEC daeString COLLADA_TYPE_IDREF_ARRAY = "idref_array";
DLLSPEC daeString COLLADA_TYPE_NAME_ARRAY = "name_array";
DLLSPEC daeString COLLADA_TYPE_BOOL_ARRAY = "bool_array";
DLLSPEC daeString COLLADA_TYPE_FLOAT_ARRAY = "float_array";
DLLSPEC daeString COLLADA_TYPE_INT_ARRAY = "int_array";
DLLSPEC daeString COLLADA_TYPE_PARAM = "param";
DLLSPEC daeString COLLADA_TYPE_ACCESSOR = "accessor";
DLLSPEC daeString COLLADA_TYPE_P = "p";
DLLSPEC daeString COLLADA_TYPE_LOOKAT = "lookat";
DLLSPEC daeString COLLADA_TYPE_MATRIX = "matrix";
DLLSPEC daeString COLLADA_TYPE_SCALE = "scale";
DLLSPEC daeString COLLADA_TYPE_SKEW = "skew";
DLLSPEC daeString COLLADA_TYPE_TRANSLATE = "translate";
DLLSPEC daeString COLLADA_TYPE_IMAGE_SOURCE = "image_source";
DLLSPEC daeString COLLADA_TYPE_REF = "ref";
DLLSPEC daeString COLLADA_TYPE_HEX = "hex";
DLLSPEC daeString COLLADA_TYPE_IMAGE_MIPS = "image_mips";
DLLSPEC daeString COLLADA_TYPE_CHANNEL = "channel";
DLLSPEC daeString COLLADA_TYPE_SAMPLER = "sampler";
DLLSPEC daeString COLLADA_TYPE_TECHNIQUE = "technique";
DLLSPEC daeString COLLADA_TYPE_EXTRA = "extra";
DLLSPEC daeString COLLADA_TYPE_POLYLIST = "polylist";
DLLSPEC daeString COLLADA_TYPE_VCOUNT = "vcount";
DLLSPEC daeString COLLADA_TYPE_POLYGONS = "polygons";
DLLSPEC daeString COLLADA_TYPE_PH = "ph";
DLLSPEC daeString COLLADA_TYPE_H = "h";
DLLSPEC daeString COLLADA_TYPE_LINESTRIPS = "linestrips";
DLLSPEC daeString COLLADA_TYPE_TRISTRIPS = "tristrips";
DLLSPEC daeString COLLADA_TYPE_LINES = "lines";
DLLSPEC daeString COLLADA_TYPE_TRIANGLES = "triangles";
DLLSPEC daeString COLLADA_TYPE_TRIFANS = "trifans";
DLLSPEC daeString COLLADA_TYPE_VERTICES = "vertices";
DLLSPEC daeString COLLADA_TYPE_ASSET = "asset";
DLLSPEC daeString COLLADA_TYPE_CONTRIBUTOR = "contributor";
DLLSPEC daeString COLLADA_TYPE_AUTHOR = "author";
DLLSPEC daeString COLLADA_TYPE_AUTHOR_EMAIL = "author_email";
DLLSPEC daeString COLLADA_TYPE_AUTHOR_WEBSITE = "author_website";
DLLSPEC daeString COLLADA_TYPE_AUTHORING_TOOL = "authoring_tool";
DLLSPEC daeString COLLADA_TYPE_COMMENTS = "comments";
DLLSPEC daeString COLLADA_TYPE_COPYRIGHT = "copyright";
DLLSPEC daeString COLLADA_TYPE_SOURCE_DATA = "source_data";
DLLSPEC daeString COLLADA_TYPE_COVERAGE = "coverage";
DLLSPEC daeString COLLADA_TYPE_GEOGRAPHIC_LOCATION = "geographic_location";
DLLSPEC daeString COLLADA_TYPE_LONGITUDE = "longitude";
DLLSPEC daeString COLLADA_TYPE_LATITUDE = "latitude";
DLLSPEC daeString COLLADA_TYPE_ALTITUDE = "altitude";
DLLSPEC daeString COLLADA_TYPE_CREATED = "created";
DLLSPEC daeString COLLADA_TYPE_KEYWORDS = "keywords";
DLLSPEC daeString COLLADA_TYPE_MODIFIED = "modified";
DLLSPEC daeString COLLADA_TYPE_REVISION = "revision";
DLLSPEC daeString COLLADA_TYPE_SUBJECT = "subject";
DLLSPEC daeString COLLADA_TYPE_TITLE = "title";
DLLSPEC daeString COLLADA_TYPE_UNIT = "unit";
DLLSPEC daeString COLLADA_TYPE_UP_AXIS = "up_axis";
DLLSPEC daeString COLLADA_TYPE_IMAGE = "image";
DLLSPEC daeString COLLADA_TYPE_RENDERABLE = "renderable";
DLLSPEC daeString COLLADA_TYPE_INIT_FROM = "init_from";
DLLSPEC daeString COLLADA_TYPE_CREATE_2D = "create_2d";
DLLSPEC daeString COLLADA_TYPE_SIZE_EXACT = "size_exact";
DLLSPEC daeString COLLADA_TYPE_SIZE_RATIO = "size_ratio";
DLLSPEC daeString COLLADA_TYPE_UNNORMALIZED = "unnormalized";
DLLSPEC daeString COLLADA_TYPE_ARRAY = "array";
DLLSPEC daeString COLLADA_TYPE_FORMAT = "format";
DLLSPEC daeString COLLADA_TYPE_HINT = "hint";
DLLSPEC daeString COLLADA_TYPE_EXACT = "exact";
DLLSPEC daeString COLLADA_TYPE_CREATE_3D = "create_3d";
DLLSPEC daeString COLLADA_TYPE_SIZE = "size";
DLLSPEC daeString COLLADA_TYPE_CREATE_CUBE = "create_cube";
DLLSPEC daeString COLLADA_TYPE_CAMERA = "camera";
DLLSPEC daeString COLLADA_TYPE_OPTICS = "optics";
DLLSPEC daeString COLLADA_TYPE_TECHNIQUE_COMMON = "technique_common";
DLLSPEC daeString COLLADA_TYPE_ORTHOGRAPHIC = "orthographic";
DLLSPEC daeString COLLADA_TYPE_PERSPECTIVE = "perspective";
DLLSPEC daeString COLLADA_TYPE_IMAGER = "imager";
DLLSPEC daeString COLLADA_TYPE_LIGHT = "light";
DLLSPEC daeString COLLADA_TYPE_AMBIENT = "ambient";
DLLSPEC daeString COLLADA_TYPE_DIRECTIONAL = "directional";
DLLSPEC daeString COLLADA_TYPE_POINT = "point";
DLLSPEC daeString COLLADA_TYPE_SPOT = "spot";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_WITH_EXTRA = "instance_with_extra";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_IMAGE = "instance_image";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_CAMERA = "instance_camera";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_FORCE_FIELD = "instance_force_field";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_LIGHT = "instance_light";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_MATERIAL = "instance_material";
DLLSPEC daeString COLLADA_TYPE_BIND = "bind";
DLLSPEC daeString COLLADA_TYPE_BIND_VERTEX_INPUT = "bind_vertex_input";
DLLSPEC daeString COLLADA_TYPE_BIND_MATERIAL = "bind_material";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_CONTROLLER = "instance_controller";
DLLSPEC daeString COLLADA_TYPE_SKELETON = "skeleton";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_GEOMETRY = "instance_geometry";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_NODE = "instance_node";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_PHYSICS_MATERIAL = "instance_physics_material";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_RIGID_CONSTRAINT = "instance_rigid_constraint";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_CAMERAS = "library_cameras";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_IMAGES = "library_images";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_LIGHTS = "library_lights";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_EFFECT = "instance_effect";
DLLSPEC daeString COLLADA_TYPE_TECHNIQUE_HINT = "technique_hint";
DLLSPEC daeString COLLADA_TYPE_SETPARAM = "setparam";
DLLSPEC daeString COLLADA_TYPE_MATERIAL = "material";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_MATERIALS = "library_materials";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLER = "fx_sampler";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLER1D = "fx_sampler1D";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLER2D = "fx_sampler2D";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLER3D = "fx_sampler3D";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLERCUBE = "fx_samplerCUBE";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLERRECT = "fx_samplerRECT";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLERDEPTH = "fx_samplerDEPTH";
DLLSPEC daeString COLLADA_TYPE_FX_RENDERTARGET = "fx_rendertarget";
DLLSPEC daeString COLLADA_TYPE_FX_COLORTARGET = "fx_colortarget";
DLLSPEC daeString COLLADA_TYPE_FX_DEPTHTARGET = "fx_depthtarget";
DLLSPEC daeString COLLADA_TYPE_FX_STENCILTARGET = "fx_stenciltarget";
DLLSPEC daeString COLLADA_TYPE_FX_CLEARCOLOR = "fx_clearcolor";
DLLSPEC daeString COLLADA_TYPE_FX_CLEARDEPTH = "fx_cleardepth";
DLLSPEC daeString COLLADA_TYPE_FX_CLEARSTENCIL = "fx_clearstencil";
DLLSPEC daeString COLLADA_TYPE_FX_ANNOTATE = "fx_annotate";
DLLSPEC daeString COLLADA_TYPE_BOOL = "bool";
DLLSPEC daeString COLLADA_TYPE_BOOL2 = "bool2";
DLLSPEC daeString COLLADA_TYPE_BOOL3 = "bool3";
DLLSPEC daeString COLLADA_TYPE_BOOL4 = "bool4";
DLLSPEC daeString COLLADA_TYPE_INT = "int";
DLLSPEC daeString COLLADA_TYPE_INT2 = "int2";
DLLSPEC daeString COLLADA_TYPE_INT3 = "int3";
DLLSPEC daeString COLLADA_TYPE_INT4 = "int4";
DLLSPEC daeString COLLADA_TYPE_FLOAT = "float";
DLLSPEC daeString COLLADA_TYPE_FLOAT2 = "float2";
DLLSPEC daeString COLLADA_TYPE_FLOAT3 = "float3";
DLLSPEC daeString COLLADA_TYPE_FLOAT4 = "float4";
DLLSPEC daeString COLLADA_TYPE_FLOAT2X2 = "float2x2";
DLLSPEC daeString COLLADA_TYPE_FLOAT3X3 = "float3x3";
DLLSPEC daeString COLLADA_TYPE_FLOAT4X4 = "float4x4";
DLLSPEC daeString COLLADA_TYPE_STRING = "string";
DLLSPEC daeString COLLADA_TYPE_FX_NEWPARAM = "fx_newparam";
DLLSPEC daeString COLLADA_TYPE_FLOAT2X1 = "float2x1";
DLLSPEC daeString COLLADA_TYPE_FLOAT2X3 = "float2x3";
DLLSPEC daeString COLLADA_TYPE_FLOAT2X4 = "float2x4";
DLLSPEC daeString COLLADA_TYPE_FLOAT3X1 = "float3x1";
DLLSPEC daeString COLLADA_TYPE_FLOAT3X2 = "float3x2";
DLLSPEC daeString COLLADA_TYPE_FLOAT3X4 = "float3x4";
DLLSPEC daeString COLLADA_TYPE_FLOAT4X1 = "float4x1";
DLLSPEC daeString COLLADA_TYPE_FLOAT4X2 = "float4x2";
DLLSPEC daeString COLLADA_TYPE_FLOAT4X3 = "float4x3";
DLLSPEC daeString COLLADA_TYPE_ENUM = "enum";
DLLSPEC daeString COLLADA_TYPE_FX_INCLUDE = "fx_include";
DLLSPEC daeString COLLADA_TYPE_FX_CODE = "fx_code";
DLLSPEC daeString COLLADA_TYPE_FX_SOURCES = "fx_sources";
DLLSPEC daeString COLLADA_TYPE_INLINE = "inline";
DLLSPEC daeString COLLADA_TYPE_IMPORT = "import";
DLLSPEC daeString COLLADA_TYPE_FX_TARGET = "fx_target";
DLLSPEC daeString COLLADA_TYPE_BINARY = "binary";
DLLSPEC daeString COLLADA_TYPE_FX_COMMON_FLOAT_OR_PARAM = "fx_common_float_or_param";
DLLSPEC daeString COLLADA_TYPE_FX_COMMON_COLOR_OR_TEXTURE = "fx_common_color_or_texture";
DLLSPEC daeString COLLADA_TYPE_COLOR = "color";
DLLSPEC daeString COLLADA_TYPE_TEXTURE = "texture";
DLLSPEC daeString COLLADA_TYPE_FX_COMMON_TRANSPARENT = "fx_common_transparent";
DLLSPEC daeString COLLADA_TYPE_FX_COMMON_NEWPARAM = "fx_common_newparam";
DLLSPEC daeString COLLADA_TYPE_SEMANTIC = "semantic";
DLLSPEC daeString COLLADA_TYPE_PROFILE_COMMON = "profile_common";
DLLSPEC daeString COLLADA_TYPE_CONSTANT = "constant";
DLLSPEC daeString COLLADA_TYPE_LAMBERT = "lambert";
DLLSPEC daeString COLLADA_TYPE_PHONG = "phong";
DLLSPEC daeString COLLADA_TYPE_BLINN = "blinn";
DLLSPEC daeString COLLADA_TYPE_PROFILE_BRIDGE = "profile_bridge";
DLLSPEC daeString COLLADA_TYPE_GLES2_NEWPARAM = "gles2_newparam";
DLLSPEC daeString COLLADA_TYPE_MODIFIER = "modifier";
DLLSPEC daeString COLLADA_TYPE_GLES2_SHADER = "gles2_shader";
DLLSPEC daeString COLLADA_TYPE_SOURCES = "sources";
DLLSPEC daeString COLLADA_TYPE_GLES2_PROGRAM = "gles2_program";
DLLSPEC daeString COLLADA_TYPE_BIND_ATTRIBUTE = "bind_attribute";
DLLSPEC daeString COLLADA_TYPE_BIND_UNIFORM = "bind_uniform";
DLLSPEC daeString COLLADA_TYPE_GLES2_PASS = "gles2_pass";
DLLSPEC daeString COLLADA_TYPE_STATES = "states";
DLLSPEC daeString COLLADA_TYPE_EVALUATE = "evaluate";
DLLSPEC daeString COLLADA_TYPE_DRAW = "draw";
DLLSPEC daeString COLLADA_TYPE_PROFILE_GLES2 = "profile_gles2";
DLLSPEC daeString COLLADA_TYPE_NEWPARAM = "newparam";
DLLSPEC daeString COLLADA_TYPE_GLSL_ARRAY = "glsl_array";
DLLSPEC daeString COLLADA_TYPE_GLSL_NEWPARAM = "glsl_newparam";
DLLSPEC daeString COLLADA_TYPE_GLSL_SHADER = "glsl_shader";
DLLSPEC daeString COLLADA_TYPE_GLSL_PROGRAM = "glsl_program";
DLLSPEC daeString COLLADA_TYPE_PROFILE_GLSL = "profile_glsl";
DLLSPEC daeString COLLADA_TYPE_PASS = "pass";
DLLSPEC daeString COLLADA_TYPE_CG_ARRAY = "cg_array";
DLLSPEC daeString COLLADA_TYPE_CG_SETPARAM = "cg_setparam";
DLLSPEC daeString COLLADA_TYPE_CG_USER = "cg_user";
DLLSPEC daeString COLLADA_TYPE_CG_NEWPARAM = "cg_newparam";
DLLSPEC daeString COLLADA_TYPE_CG_PASS = "cg_pass";
DLLSPEC daeString COLLADA_TYPE_PROGRAM = "program";
DLLSPEC daeString COLLADA_TYPE_SHADER = "shader";
DLLSPEC daeString COLLADA_TYPE_PROFILE_CG = "profile_cg";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXTURE_CONSTANT = "gles_texture_constant";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXENV_COMMAND = "gles_texenv_command";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXCOMBINER_ARGUMENT_RGB = "gles_texcombiner_argument_rgb";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXCOMBINER_ARGUMENT_ALPHA = "gles_texcombiner_argument_alpha";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXCOMBINER_COMMAND_RGB = "gles_texcombiner_command_rgb";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXCOMBINER_COMMAND_ALPHA = "gles_texcombiner_command_alpha";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXCOMBINER_COMMAND = "gles_texcombiner_command";
DLLSPEC daeString COLLADA_TYPE_GLES_TEXTURE_PIPELINE = "gles_texture_pipeline";
DLLSPEC daeString COLLADA_TYPE_GLES_SAMPLER = "gles_sampler";
DLLSPEC daeString COLLADA_TYPE_TEXCOORD = "texcoord";
DLLSPEC daeString COLLADA_TYPE_GLES_NEWPARAM = "gles_newparam";
DLLSPEC daeString COLLADA_TYPE_PROFILE_GLES = "profile_gles";
DLLSPEC daeString COLLADA_TYPE_EFFECT = "effect";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_EFFECTS = "library_effects";
DLLSPEC daeString COLLADA_TYPE_BOX = "box";
DLLSPEC daeString COLLADA_TYPE_HALF_EXTENTS = "half_extents";
DLLSPEC daeString COLLADA_TYPE_PLANE = "plane";
DLLSPEC daeString COLLADA_TYPE_EQUATION = "equation";
DLLSPEC daeString COLLADA_TYPE_SPHERE = "sphere";
DLLSPEC daeString COLLADA_TYPE_RADIUS = "radius";
DLLSPEC daeString COLLADA_TYPE_ELLIPSOID = "ellipsoid";
DLLSPEC daeString COLLADA_TYPE_CYLINDER = "cylinder";
DLLSPEC daeString COLLADA_TYPE_HEIGHT = "height";
DLLSPEC daeString COLLADA_TYPE_CAPSULE = "capsule";
DLLSPEC daeString COLLADA_TYPE_FORCE_FIELD = "force_field";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_FORCE_FIELDS = "library_force_fields";
DLLSPEC daeString COLLADA_TYPE_PHYSICS_MATERIAL = "physics_material";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_PHYSICS_MATERIALS = "library_physics_materials";
DLLSPEC daeString COLLADA_TYPE_EDGES = "edges";
DLLSPEC daeString COLLADA_TYPE_WIRES = "wires";
DLLSPEC daeString COLLADA_TYPE_FACES = "faces";
DLLSPEC daeString COLLADA_TYPE_SHELLS = "shells";
DLLSPEC daeString COLLADA_TYPE_SOLIDS = "solids";
DLLSPEC daeString COLLADA_TYPE_LINE = "line";
DLLSPEC daeString COLLADA_TYPE_ORIGIN = "origin";
DLLSPEC daeString COLLADA_TYPE_DIRECTION = "direction";
DLLSPEC daeString COLLADA_TYPE_CIRCLE = "circle";
DLLSPEC daeString COLLADA_TYPE_ELLIPSE = "ellipse";
DLLSPEC daeString COLLADA_TYPE_PARABOLA = "parabola";
DLLSPEC daeString COLLADA_TYPE_FOCAL = "focal";
DLLSPEC daeString COLLADA_TYPE_HYPERBOLA = "hyperbola";
DLLSPEC daeString COLLADA_TYPE_TORUS = "torus";
DLLSPEC daeString COLLADA_TYPE_PCURVES = "pcurves";
DLLSPEC daeString COLLADA_TYPE_SIDREF_ARRAY = "sidref_array";
DLLSPEC daeString COLLADA_TYPE_SOURCE = "source";
DLLSPEC daeString COLLADA_TYPE_ANIMATION = "animation";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_ANIMATIONS = "library_animations";
DLLSPEC daeString COLLADA_TYPE_SKIN = "skin";
DLLSPEC daeString COLLADA_TYPE_BIND_SHAPE_MATRIX = "bind_shape_matrix";
DLLSPEC daeString COLLADA_TYPE_JOINTS = "joints";
DLLSPEC daeString COLLADA_TYPE_VERTEX_WEIGHTS = "vertex_weights";
DLLSPEC daeString COLLADA_TYPE_V = "v";
DLLSPEC daeString COLLADA_TYPE_CONVEX_MESH = "convex_mesh";
DLLSPEC daeString COLLADA_TYPE_MESH = "mesh";
DLLSPEC daeString COLLADA_TYPE_SPLINE = "spline";
DLLSPEC daeString COLLADA_TYPE_CONTROL_VERTICES = "control_vertices";
DLLSPEC daeString COLLADA_TYPE_NURBS_SURFACE = "nurbs_surface";
DLLSPEC daeString COLLADA_TYPE_NURBS = "nurbs";
DLLSPEC daeString COLLADA_TYPE_MORPH = "morph";
DLLSPEC daeString COLLADA_TYPE_TARGETS = "targets";
DLLSPEC daeString COLLADA_TYPE_CONTROLLER = "controller";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_CONTROLLERS = "library_controllers";
DLLSPEC daeString COLLADA_TYPE_ORIENT = "orient";
DLLSPEC daeString COLLADA_TYPE_CURVE = "curve";
DLLSPEC daeString COLLADA_TYPE_SURFACE_CURVES = "surface_curves";
DLLSPEC daeString COLLADA_TYPE_CURVES = "curves";
DLLSPEC daeString COLLADA_TYPE_SWEPT_SURFACE = "swept_surface";
DLLSPEC daeString COLLADA_TYPE_AXIS = "axis";
DLLSPEC daeString COLLADA_TYPE_CONE = "cone";
DLLSPEC daeString COLLADA_TYPE_ANGLE = "angle";
DLLSPEC daeString COLLADA_TYPE_SURFACE = "surface";
DLLSPEC daeString COLLADA_TYPE_SURFACES = "surfaces";
DLLSPEC daeString COLLADA_TYPE_BREP = "brep";
DLLSPEC daeString COLLADA_TYPE_GEOMETRY = "geometry";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_GEOMETRIES = "library_geometries";
DLLSPEC daeString COLLADA_TYPE_LIMITS_SUB = "limits_sub";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_JOINT = "instance_joint";
DLLSPEC daeString COLLADA_TYPE_TARGETABLE_FLOAT4 = "targetable_float4";
DLLSPEC daeString COLLADA_TYPE_ROTATE = "rotate";
DLLSPEC daeString COLLADA_TYPE_LINK = "link";
DLLSPEC daeString COLLADA_TYPE_ATTACHMENT_FULL = "attachment_full";
DLLSPEC daeString COLLADA_TYPE_ATTACHMENT_START = "attachment_start";
DLLSPEC daeString COLLADA_TYPE_ATTACHMENT_END = "attachment_end";
DLLSPEC daeString COLLADA_TYPE_RIGID_CONSTRAINT = "rigid_constraint";
DLLSPEC daeString COLLADA_TYPE_REF_ATTACHMENT = "ref_attachment";
DLLSPEC daeString COLLADA_TYPE_ATTACHMENT = "attachment";
DLLSPEC daeString COLLADA_TYPE_ENABLED = "enabled";
DLLSPEC daeString COLLADA_TYPE_INTERPENETRATE = "interpenetrate";
DLLSPEC daeString COLLADA_TYPE_LIMITS = "limits";
DLLSPEC daeString COLLADA_TYPE_SWING_CONE_AND_TWIST = "swing_cone_and_twist";
DLLSPEC daeString COLLADA_TYPE_LINEAR = "linear";
DLLSPEC daeString COLLADA_TYPE_SPRING = "spring";
DLLSPEC daeString COLLADA_TYPE_ANGULAR = "angular";
DLLSPEC daeString COLLADA_TYPE_NODE = "node";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_NODES = "library_nodes";
DLLSPEC daeString COLLADA_TYPE_VISUAL_SCENE = "visual_scene";
DLLSPEC daeString COLLADA_TYPE_EVALUATE_SCENE = "evaluate_scene";
DLLSPEC daeString COLLADA_TYPE_RENDER = "render";
DLLSPEC daeString COLLADA_TYPE_LAYER = "layer";
DLLSPEC daeString COLLADA_TYPE_TECHNIQUE_OVERRIDE = "technique_override";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_VISUAL_SCENES = "library_visual_scenes";
DLLSPEC daeString COLLADA_TYPE_RIGID_BODY = "rigid_body";
DLLSPEC daeString COLLADA_TYPE_DYNAMIC = "dynamic";
DLLSPEC daeString COLLADA_TYPE_MASS_FRAME = "mass_frame";
DLLSPEC daeString COLLADA_TYPE_SHAPE = "shape";
DLLSPEC daeString COLLADA_TYPE_HOLLOW = "hollow";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_RIGID_BODY = "instance_rigid_body";
DLLSPEC daeString COLLADA_TYPE_ANGULAR_VELOCITY = "angular_velocity";
DLLSPEC daeString COLLADA_TYPE_VELOCITY = "velocity";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_PHYSICS_MODEL = "instance_physics_model";
DLLSPEC daeString COLLADA_TYPE_PHYSICS_MODEL = "physics_model";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_PHYSICS_MODELS = "library_physics_models";
DLLSPEC daeString COLLADA_TYPE_PHYSICS_SCENE = "physics_scene";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_PHYSICS_SCENES = "library_physics_scenes";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_NEWPARAM = "kinematics_newparam";
DLLSPEC daeString COLLADA_TYPE_SIDREF = "SIDREF";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_FRAME = "kinematics_frame";
DLLSPEC daeString COLLADA_TYPE_COMMON_PARAM = "common_param";
DLLSPEC daeString COLLADA_TYPE_COMMON_INT_OR_PARAM = "common_int_or_param";
DLLSPEC daeString COLLADA_TYPE_COMMON_BOOL_OR_PARAM = "common_bool_or_param";
DLLSPEC daeString COLLADA_TYPE_COMMON_FLOAT_OR_PARAM = "common_float_or_param";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_LIMITS = "kinematics_limits";
DLLSPEC daeString COLLADA_TYPE_COMMON_SIDREF_OR_PARAM = "common_sidref_or_param";
DLLSPEC daeString COLLADA_TYPE_BIND_JOINT_AXIS = "bind_joint_axis";
DLLSPEC daeString COLLADA_TYPE_BIND_KINEMATICS_MODEL = "bind_kinematics_model";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_CONNECT_PARAM = "kinematics_connect_param";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_SETPARAM = "kinematics_setparam";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_KINEMATICS_SCENE = "instance_kinematics_scene";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_INDEX = "kinematics_index";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_PARAM = "kinematics_param";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_BIND = "kinematics_bind";
DLLSPEC daeString COLLADA_TYPE_MOTION_AXIS_INFO = "motion_axis_info";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_KINEMATICS_MODEL = "instance_kinematics_model";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_ARTICULATED_SYSTEM = "instance_articulated_system";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_SCENE = "kinematics_scene";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_KINEMATICS_SCENES = "library_kinematics_scenes";
DLLSPEC daeString COLLADA_TYPE_COMMON_FLOAT2_OR_PARAM = "common_float2_or_param";
DLLSPEC daeString COLLADA_TYPE_MOTION_EFFECTOR_INFO = "motion_effector_info";
DLLSPEC daeString COLLADA_TYPE_MOTION_TECHNIQUE = "motion_technique";
DLLSPEC daeString COLLADA_TYPE_MOTION = "motion";
DLLSPEC daeString COLLADA_TYPE_MINMAX = "minmax";
DLLSPEC daeString COLLADA_TYPE_JOINT_LIMITS = "joint_limits";
DLLSPEC daeString COLLADA_TYPE_AXIS_CONSTRAINT = "axis_constraint";
DLLSPEC daeString COLLADA_TYPE_JOINT = "joint";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_JOINTS = "library_joints";
DLLSPEC daeString COLLADA_TYPE_FORMULA_TECHNIQUE = "formula_technique";
DLLSPEC daeString COLLADA_TYPE_FORMULA_NEWPARAM = "formula_newparam";
DLLSPEC daeString COLLADA_TYPE_FORMULA_SETPARAM = "formula_setparam";
DLLSPEC daeString COLLADA_TYPE_INSTANCE_FORMULA = "instance_formula";
DLLSPEC daeString COLLADA_TYPE_ANIMATION_CLIP = "animation_clip";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_ANIMATION_CLIPS = "library_animation_clips";
DLLSPEC daeString COLLADA_TYPE_FORMULA = "formula";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_MODEL_TECHNIQUE = "kinematics_model_technique";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_MODEL = "kinematics_model";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_KINEMATICS_MODELS = "library_kinematics_models";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_AXIS_INFO = "kinematics_axis_info";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS_TECHNIQUE = "kinematics_technique";
DLLSPEC daeString COLLADA_TYPE_KINEMATICS = "kinematics";
DLLSPEC daeString COLLADA_TYPE_ARTICULATED_SYSTEM = "articulated_system";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_ARTICULATED_SYSTEMS = "library_articulated_systems";
DLLSPEC daeString COLLADA_TYPE_LIBRARY_FORMULAS = "library_formulas";
DLLSPEC daeString COLLADA_TYPE_FX_SAMPLER_STATES = "fx_sampler_states";
DLLSPEC daeString COLLADA_TYPE_WRAP_S = "wrap_s";
DLLSPEC daeString COLLADA_TYPE_WRAP_T = "wrap_t";
DLLSPEC daeString COLLADA_TYPE_WRAP_P = "wrap_p";
DLLSPEC daeString COLLADA_TYPE_MINFILTER = "minfilter";
DLLSPEC daeString COLLADA_TYPE_MAGFILTER = "magfilter";
DLLSPEC daeString COLLADA_TYPE_MIPFILTER = "mipfilter";
DLLSPEC daeString COLLADA_TYPE_BORDER_COLOR = "border_color";
DLLSPEC daeString COLLADA_TYPE_MIP_MAX_LEVEL = "mip_max_level";
DLLSPEC daeString COLLADA_TYPE_MIP_MIN_LEVEL = "mip_min_level";
DLLSPEC daeString COLLADA_TYPE_MIP_BIAS = "mip_bias";
DLLSPEC daeString COLLADA_TYPE_MAX_ANISOTROPY = "max_anisotropy";
DLLSPEC daeString COLLADA_TYPE_FX_SETPARAM = "fx_setparam";
DLLSPEC daeString COLLADA_TYPE_SAMPLER_STATES = "sampler_states";
DLLSPEC daeString COLLADA_TYPE_GL_PIPELINE_SETTINGS = "gl_pipeline_settings";
DLLSPEC daeString COLLADA_TYPE_ALPHA_FUNC = "alpha_func";
DLLSPEC daeString COLLADA_TYPE_FUNC = "func";
DLLSPEC daeString COLLADA_TYPE_VALUE = "value";
DLLSPEC daeString COLLADA_TYPE_BLEND_FUNC = "blend_func";
DLLSPEC daeString COLLADA_TYPE_SRC = "src";
DLLSPEC daeString COLLADA_TYPE_DEST = "dest";
DLLSPEC daeString COLLADA_TYPE_BLEND_FUNC_SEPARATE = "blend_func_separate";
DLLSPEC daeString COLLADA_TYPE_SRC_RGB = "src_rgb";
DLLSPEC daeString COLLADA_TYPE_DEST_RGB = "dest_rgb";
DLLSPEC daeString COLLADA_TYPE_SRC_ALPHA = "src_alpha";
DLLSPEC daeString COLLADA_TYPE_DEST_ALPHA = "dest_alpha";
DLLSPEC daeString COLLADA_TYPE_BLEND_EQUATION = "blend_equation";
DLLSPEC daeString COLLADA_TYPE_BLEND_EQUATION_SEPARATE = "blend_equation_separate";
DLLSPEC daeString COLLADA_TYPE_RGB = "rgb";
DLLSPEC daeString COLLADA_TYPE_ALPHA = "alpha";
DLLSPEC daeString COLLADA_TYPE_COLOR_MATERIAL = "color_material";
DLLSPEC daeString COLLADA_TYPE_FACE = "face";
DLLSPEC daeString COLLADA_TYPE_MODE = "mode";
DLLSPEC daeString COLLADA_TYPE_CULL_FACE = "cull_face";
DLLSPEC daeString COLLADA_TYPE_DEPTH_FUNC = "depth_func";
DLLSPEC daeString COLLADA_TYPE_FOG_MODE = "fog_mode";
DLLSPEC daeString COLLADA_TYPE_FOG_COORD_SRC = "fog_coord_src";
DLLSPEC daeString COLLADA_TYPE_FRONT_FACE = "front_face";
DLLSPEC daeString COLLADA_TYPE_LIGHT_MODEL_COLOR_CONTROL = "light_model_color_control";
DLLSPEC daeString COLLADA_TYPE_LOGIC_OP = "logic_op";
DLLSPEC daeString COLLADA_TYPE_POLYGON_MODE = "polygon_mode";
DLLSPEC daeString COLLADA_TYPE_SHADE_MODEL = "shade_model";
DLLSPEC daeString COLLADA_TYPE_STENCIL_FUNC = "stencil_func";
DLLSPEC daeString COLLADA_TYPE_MASK = "mask";
DLLSPEC daeString COLLADA_TYPE_STENCIL_OP = "stencil_op";
DLLSPEC daeString COLLADA_TYPE_FAIL = "fail";
DLLSPEC daeString COLLADA_TYPE_ZFAIL = "zfail";
DLLSPEC daeString COLLADA_TYPE_ZPASS = "zpass";
DLLSPEC daeString COLLADA_TYPE_STENCIL_FUNC_SEPARATE = "stencil_func_separate";
DLLSPEC daeString COLLADA_TYPE_FRONT = "front";
DLLSPEC daeString COLLADA_TYPE_BACK = "back";
DLLSPEC daeString COLLADA_TYPE_STENCIL_OP_SEPARATE = "stencil_op_separate";
DLLSPEC daeString COLLADA_TYPE_STENCIL_MASK_SEPARATE = "stencil_mask_separate";
DLLSPEC daeString COLLADA_TYPE_LIGHT_ENABLE = "light_enable";
DLLSPEC daeString COLLADA_TYPE_LIGHT_AMBIENT = "light_ambient";
DLLSPEC daeString COLLADA_TYPE_LIGHT_DIFFUSE = "light_diffuse";
DLLSPEC daeString COLLADA_TYPE_LIGHT_SPECULAR = "light_specular";
DLLSPEC daeString COLLADA_TYPE_LIGHT_POSITION = "light_position";
DLLSPEC daeString COLLADA_TYPE_LIGHT_CONSTANT_ATTENUATION = "light_constant_attenuation";
DLLSPEC daeString COLLADA_TYPE_LIGHT_LINEAR_ATTENUATION = "light_linear_attenuation";
DLLSPEC daeString COLLADA_TYPE_LIGHT_QUADRATIC_ATTENUATION = "light_quadratic_attenuation";
DLLSPEC daeString COLLADA_TYPE_LIGHT_SPOT_CUTOFF = "light_spot_cutoff";
DLLSPEC daeString COLLADA_TYPE_LIGHT_SPOT_DIRECTION = "light_spot_direction";
DLLSPEC daeString COLLADA_TYPE_LIGHT_SPOT_EXPONENT = "light_spot_exponent";
DLLSPEC daeString COLLADA_TYPE_TEXTURE1D = "texture1D";
DLLSPEC daeString COLLADA_TYPE_TEXTURE2D = "texture2D";
DLLSPEC daeString COLLADA_TYPE_TEXTURE3D = "texture3D";
DLLSPEC daeString COLLADA_TYPE_TEXTURECUBE = "textureCUBE";
DLLSPEC daeString COLLADA_TYPE_TEXTURERECT = "textureRECT";
DLLSPEC daeString COLLADA_TYPE_TEXTUREDEPTH = "textureDEPTH";
DLLSPEC daeString COLLADA_TYPE_TEXTURE1D_ENABLE = "texture1D_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTURE2D_ENABLE = "texture2D_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTURE3D_ENABLE = "texture3D_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTURECUBE_ENABLE = "textureCUBE_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTURERECT_ENABLE = "textureRECT_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTUREDEPTH_ENABLE = "textureDEPTH_enable";
DLLSPEC daeString COLLADA_TYPE_TEXTURE_ENV_COLOR = "texture_env_color";
DLLSPEC daeString COLLADA_TYPE_TEXTURE_ENV_MODE = "texture_env_mode";
DLLSPEC daeString COLLADA_TYPE_CLIP_PLANE = "clip_plane";
DLLSPEC daeString COLLADA_TYPE_CLIP_PLANE_ENABLE = "clip_plane_enable";
DLLSPEC daeString COLLADA_TYPE_BLEND_COLOR = "blend_color";
DLLSPEC daeString COLLADA_TYPE_COLOR_MASK = "color_mask";
DLLSPEC daeString COLLADA_TYPE_DEPTH_BOUNDS = "depth_bounds";
DLLSPEC daeString COLLADA_TYPE_DEPTH_MASK = "depth_mask";
DLLSPEC daeString COLLADA_TYPE_DEPTH_RANGE = "depth_range";
DLLSPEC daeString COLLADA_TYPE_FOG_DENSITY = "fog_density";
DLLSPEC daeString COLLADA_TYPE_FOG_START = "fog_start";
DLLSPEC daeString COLLADA_TYPE_FOG_END = "fog_end";
DLLSPEC daeString COLLADA_TYPE_FOG_COLOR = "fog_color";
DLLSPEC daeString COLLADA_TYPE_LIGHT_MODEL_AMBIENT = "light_model_ambient";
DLLSPEC daeString COLLADA_TYPE_LIGHTING_ENABLE = "lighting_enable";
DLLSPEC daeString COLLADA_TYPE_LINE_STIPPLE = "line_stipple";
DLLSPEC daeString COLLADA_TYPE_LINE_WIDTH = "line_width";
DLLSPEC daeString COLLADA_TYPE_MATERIAL_AMBIENT = "material_ambient";
DLLSPEC daeString COLLADA_TYPE_MATERIAL_DIFFUSE = "material_diffuse";
DLLSPEC daeString COLLADA_TYPE_MATERIAL_EMISSION = "material_emission";
DLLSPEC daeString COLLADA_TYPE_MATERIAL_SHININESS = "material_shininess";
DLLSPEC daeString COLLADA_TYPE_MATERIAL_SPECULAR = "material_specular";
DLLSPEC daeString COLLADA_TYPE_MODEL_VIEW_MATRIX = "model_view_matrix";
DLLSPEC daeString COLLADA_TYPE_POINT_DISTANCE_ATTENUATION = "point_distance_attenuation";
DLLSPEC daeString COLLADA_TYPE_POINT_FADE_THRESHOLD_SIZE = "point_fade_threshold_size";
DLLSPEC daeString COLLADA_TYPE_POINT_SIZE = "point_size";
DLLSPEC daeString COLLADA_TYPE_POINT_SIZE_MIN = "point_size_min";
DLLSPEC daeString COLLADA_TYPE_POINT_SIZE_MAX = "point_size_max";
DLLSPEC daeString COLLADA_TYPE_POLYGON_OFFSET = "polygon_offset";
DLLSPEC daeString COLLADA_TYPE_PROJECTION_MATRIX = "projection_matrix";
DLLSPEC daeString COLLADA_TYPE_SCISSOR = "scissor";
DLLSPEC daeString COLLADA_TYPE_STENCIL_MASK = "stencil_mask";
DLLSPEC daeString COLLADA_TYPE_ALPHA_TEST_ENABLE = "alpha_test_enable";
DLLSPEC daeString COLLADA_TYPE_BLEND_ENABLE = "blend_enable";
DLLSPEC daeString COLLADA_TYPE_COLOR_LOGIC_OP_ENABLE = "color_logic_op_enable";
DLLSPEC daeString COLLADA_TYPE_COLOR_MATERIAL_ENABLE = "color_material_enable";
DLLSPEC daeString COLLADA_TYPE_CULL_FACE_ENABLE = "cull_face_enable";
DLLSPEC daeString COLLADA_TYPE_DEPTH_BOUNDS_ENABLE = "depth_bounds_enable";
DLLSPEC daeString COLLADA_TYPE_DEPTH_CLAMP_ENABLE = "depth_clamp_enable";
DLLSPEC daeString COLLADA_TYPE_DEPTH_TEST_ENABLE = "depth_test_enable";
DLLSPEC daeString COLLADA_TYPE_DITHER_ENABLE = "dither_enable";
DLLSPEC daeString COLLADA_TYPE_FOG_ENABLE = "fog_enable";
DLLSPEC daeString COLLADA_TYPE_LIGHT_MODEL_LOCAL_VIEWER_ENABLE = "light_model_local_viewer_enable";
DLLSPEC daeString COLLADA_TYPE_LIGHT_MODEL_TWO_SIDE_ENABLE = "light_model_two_side_enable";
DLLSPEC daeString COLLADA_TYPE_LINE_SMOOTH_ENABLE = "line_smooth_enable";
DLLSPEC daeString COLLADA_TYPE_LINE_STIPPLE_ENABLE = "line_stipple_enable";
DLLSPEC daeString COLLADA_TYPE_LOGIC_OP_ENABLE = "logic_op_enable";
DLLSPEC daeString COLLADA_TYPE_MULTISAMPLE_ENABLE = "multisample_enable";
DLLSPEC daeString COLLADA_TYPE_NORMALIZE_ENABLE = "normalize_enable";
DLLSPEC daeString COLLADA_TYPE_POINT_SMOOTH_ENABLE = "point_smooth_enable";
DLLSPEC daeString COLLADA_TYPE_POLYGON_OFFSET_FILL_ENABLE = "polygon_offset_fill_enable";
DLLSPEC daeString COLLADA_TYPE_POLYGON_OFFSET_LINE_ENABLE = "polygon_offset_line_enable";
DLLSPEC daeString COLLADA_TYPE_POLYGON_OFFSET_POINT_ENABLE = "polygon_offset_point_enable";
DLLSPEC daeString COLLADA_TYPE_POLYGON_SMOOTH_ENABLE = "polygon_smooth_enable";
DLLSPEC daeString COLLADA_TYPE_POLYGON_STIPPLE_ENABLE = "polygon_stipple_enable";
DLLSPEC daeString COLLADA_TYPE_RESCALE_NORMAL_ENABLE = "rescale_normal_enable";
DLLSPEC daeString COLLADA_TYPE_SAMPLE_ALPHA_TO_COVERAGE_ENABLE = "sample_alpha_to_coverage_enable";
DLLSPEC daeString COLLADA_TYPE_SAMPLE_ALPHA_TO_ONE_ENABLE = "sample_alpha_to_one_enable";
DLLSPEC daeString COLLADA_TYPE_SAMPLE_COVERAGE_ENABLE = "sample_coverage_enable";
DLLSPEC daeString COLLADA_TYPE_SCISSOR_TEST_ENABLE = "scissor_test_enable";
DLLSPEC daeString COLLADA_TYPE_STENCIL_TEST_ENABLE = "stencil_test_enable";
DLLSPEC daeString COLLADA_TYPE_GLES2_PIPELINE_SETTINGS = "gles2_pipeline_settings";
DLLSPEC daeString COLLADA_TYPE_SAMPLE_COVERAGE = "sample_coverage";
DLLSPEC daeString COLLADA_TYPE_INVERT = "invert";
DLLSPEC daeString COLLADA_TYPE_POINT_SIZE_ENABLE = "point_size_enable";
DLLSPEC daeString COLLADA_TYPE_GLES2_VALUE = "gles2_value";
DLLSPEC daeString COLLADA_TYPE_BVEC2 = "bvec2";
DLLSPEC daeString COLLADA_TYPE_BVEC3 = "bvec3";
DLLSPEC daeString COLLADA_TYPE_BVEC4 = "bvec4";
DLLSPEC daeString COLLADA_TYPE_VEC2 = "vec2";
DLLSPEC daeString COLLADA_TYPE_VEC3 = "vec3";
DLLSPEC daeString COLLADA_TYPE_VEC4 = "vec4";
DLLSPEC daeString COLLADA_TYPE_MAT2 = "mat2";
DLLSPEC daeString COLLADA_TYPE_MAT3 = "mat3";
DLLSPEC daeString COLLADA_TYPE_MAT4 = "mat4";
DLLSPEC daeString COLLADA_TYPE_IVEC2 = "ivec2";
DLLSPEC daeString COLLADA_TYPE_IVEC3 = "ivec3";
DLLSPEC daeString COLLADA_TYPE_IVEC4 = "ivec4";
DLLSPEC daeString COLLADA_TYPE_USERTYPE = "usertype";
DLLSPEC daeString COLLADA_TYPE_GLSL_VALUE = "glsl_value";
DLLSPEC daeString COLLADA_TYPE_CG_PARAM = "cg_param";
DLLSPEC daeString COLLADA_TYPE_BOOL2X1 = "bool2x1";
DLLSPEC daeString COLLADA_TYPE_BOOL2X2 = "bool2x2";
DLLSPEC daeString COLLADA_TYPE_BOOL2X3 = "bool2x3";
DLLSPEC daeString COLLADA_TYPE_BOOL2X4 = "bool2x4";
DLLSPEC daeString COLLADA_TYPE_BOOL3X1 = "bool3x1";
DLLSPEC daeString COLLADA_TYPE_BOOL3X2 = "bool3x2";
DLLSPEC daeString COLLADA_TYPE_BOOL3X3 = "bool3x3";
DLLSPEC daeString COLLADA_TYPE_BOOL3X4 = "bool3x4";
DLLSPEC daeString COLLADA_TYPE_BOOL4X1 = "bool4x1";
DLLSPEC daeString COLLADA_TYPE_BOOL4X2 = "bool4x2";
DLLSPEC daeString COLLADA_TYPE_BOOL4X3 = "bool4x3";
DLLSPEC daeString COLLADA_TYPE_BOOL4X4 = "bool4x4";
DLLSPEC daeString COLLADA_TYPE_INT2X1 = "int2x1";
DLLSPEC daeString COLLADA_TYPE_INT2X2 = "int2x2";
DLLSPEC daeString COLLADA_TYPE_INT2X3 = "int2x3";
DLLSPEC daeString COLLADA_TYPE_INT2X4 = "int2x4";
DLLSPEC daeString COLLADA_TYPE_INT3X1 = "int3x1";
DLLSPEC daeString COLLADA_TYPE_INT3X2 = "int3x2";
DLLSPEC daeString COLLADA_TYPE_INT3X3 = "int3x3";
DLLSPEC daeString COLLADA_TYPE_INT3X4 = "int3x4";
DLLSPEC daeString COLLADA_TYPE_INT4X1 = "int4x1";
DLLSPEC daeString COLLADA_TYPE_INT4X2 = "int4x2";
DLLSPEC daeString COLLADA_TYPE_INT4X3 = "int4x3";
DLLSPEC daeString COLLADA_TYPE_INT4X4 = "int4x4";
DLLSPEC daeString COLLADA_TYPE_HALF = "half";
DLLSPEC daeString COLLADA_TYPE_HALF2 = "half2";
DLLSPEC daeString COLLADA_TYPE_HALF3 = "half3";
DLLSPEC daeString COLLADA_TYPE_HALF4 = "half4";
DLLSPEC daeString COLLADA_TYPE_HALF2X1 = "half2x1";
DLLSPEC daeString COLLADA_TYPE_HALF2X2 = "half2x2";
DLLSPEC daeString COLLADA_TYPE_HALF2X3 = "half2x3";
DLLSPEC daeString COLLADA_TYPE_HALF2X4 = "half2x4";
DLLSPEC daeString COLLADA_TYPE_HALF3X1 = "half3x1";
DLLSPEC daeString COLLADA_TYPE_HALF3X2 = "half3x2";
DLLSPEC daeString COLLADA_TYPE_HALF3X3 = "half3x3";
DLLSPEC daeString COLLADA_TYPE_HALF3X4 = "half3x4";
DLLSPEC daeString COLLADA_TYPE_HALF4X1 = "half4x1";
DLLSPEC daeString COLLADA_TYPE_HALF4X2 = "half4x2";
DLLSPEC daeString COLLADA_TYPE_HALF4X3 = "half4x3";
DLLSPEC daeString COLLADA_TYPE_HALF4X4 = "half4x4";
DLLSPEC daeString COLLADA_TYPE_FIXED = "fixed";
DLLSPEC daeString COLLADA_TYPE_FIXED2 = "fixed2";
DLLSPEC daeString COLLADA_TYPE_FIXED3 = "fixed3";
DLLSPEC daeString COLLADA_TYPE_FIXED4 = "fixed4";
DLLSPEC daeString COLLADA_TYPE_FIXED2X1 = "fixed2x1";
DLLSPEC daeString COLLADA_TYPE_FIXED2X2 = "fixed2x2";
DLLSPEC daeString COLLADA_TYPE_FIXED2X3 = "fixed2x3";
DLLSPEC daeString COLLADA_TYPE_FIXED2X4 = "fixed2x4";
DLLSPEC daeString COLLADA_TYPE_FIXED3X1 = "fixed3x1";
DLLSPEC daeString COLLADA_TYPE_FIXED3X2 = "fixed3x2";
DLLSPEC daeString COLLADA_TYPE_FIXED3X3 = "fixed3x3";
DLLSPEC daeString COLLADA_TYPE_FIXED3X4 = "fixed3x4";
DLLSPEC daeString COLLADA_TYPE_FIXED4X1 = "fixed4x1";
DLLSPEC daeString COLLADA_TYPE_FIXED4X2 = "fixed4x2";
DLLSPEC daeString COLLADA_TYPE_FIXED4X3 = "fixed4x3";
DLLSPEC daeString COLLADA_TYPE_FIXED4X4 = "fixed4x4";
DLLSPEC daeString COLLADA_TYPE_GLES_SAMPLER_STATES = "gles_sampler_states";
DLLSPEC daeString COLLADA_TYPE_GLES_PIPELINE_SETTINGS = "gles_pipeline_settings";
DLLSPEC daeString COLLADA_TYPE_TEXTURE_PIPELINE = "texture_pipeline";
DLLSPEC daeString COLLADA_TYPE_GLES_PARAM = "gles_param";
DLLSPEC daeString COLLADA_TYPE_FLOAT1X1 = "float1x1";
DLLSPEC daeString COLLADA_TYPE_FLOAT1X2 = "float1x2";
DLLSPEC daeString COLLADA_TYPE_FLOAT1X3 = "float1x3";
DLLSPEC daeString COLLADA_TYPE_FLOAT1X4 = "float1x4";
DLLSPEC daeString COLLADA_TYPE_FX_PROFILE = "fx_profile";
DLLSPEC daeString COLLADA_TYPE_COLLADA = "COLLADA";
DLLSPEC daeString COLLADA_TYPE_SCENE = "scene";

DLLSPEC daeString COLLADA_ELEMENT_COLLADA = "COLLADA";
DLLSPEC daeString COLLADA_ELEMENT_PARAM = "param";
DLLSPEC daeString COLLADA_ELEMENT_REF = "ref";
DLLSPEC daeString COLLADA_ELEMENT_HEX = "hex";
DLLSPEC daeString COLLADA_ELEMENT_INPUT = "input";
DLLSPEC daeString COLLADA_ELEMENT_ASSET = "asset";
DLLSPEC daeString COLLADA_ELEMENT_TECHNIQUE = "technique";
DLLSPEC daeString COLLADA_ELEMENT_VCOUNT = "vcount";
DLLSPEC daeString COLLADA_ELEMENT_P = "p";
DLLSPEC daeString COLLADA_ELEMENT_EXTRA = "extra";
DLLSPEC daeString COLLADA_ELEMENT_PH = "ph";
DLLSPEC daeString COLLADA_ELEMENT_H = "h";
DLLSPEC daeString COLLADA_ELEMENT_CONTRIBUTOR = "contributor";
DLLSPEC daeString COLLADA_ELEMENT_COVERAGE = "coverage";
DLLSPEC daeString COLLADA_ELEMENT_CREATED = "created";
DLLSPEC daeString COLLADA_ELEMENT_KEYWORDS = "keywords";
DLLSPEC daeString COLLADA_ELEMENT_MODIFIED = "modified";
DLLSPEC daeString COLLADA_ELEMENT_REVISION = "revision";
DLLSPEC daeString COLLADA_ELEMENT_SUBJECT = "subject";
DLLSPEC daeString COLLADA_ELEMENT_TITLE = "title";
DLLSPEC daeString COLLADA_ELEMENT_UNIT = "unit";
DLLSPEC daeString COLLADA_ELEMENT_UP_AXIS = "up_axis";
DLLSPEC daeString COLLADA_ELEMENT_AUTHOR = "author";
DLLSPEC daeString COLLADA_ELEMENT_AUTHOR_EMAIL = "author_email";
DLLSPEC daeString COLLADA_ELEMENT_AUTHOR_WEBSITE = "author_website";
DLLSPEC daeString COLLADA_ELEMENT_AUTHORING_TOOL = "authoring_tool";
DLLSPEC daeString COLLADA_ELEMENT_COMMENTS = "comments";
DLLSPEC daeString COLLADA_ELEMENT_COPYRIGHT = "copyright";
DLLSPEC daeString COLLADA_ELEMENT_SOURCE_DATA = "source_data";
DLLSPEC daeString COLLADA_ELEMENT_GEOGRAPHIC_LOCATION = "geographic_location";
DLLSPEC daeString COLLADA_ELEMENT_LONGITUDE = "longitude";
DLLSPEC daeString COLLADA_ELEMENT_LATITUDE = "latitude";
DLLSPEC daeString COLLADA_ELEMENT_ALTITUDE = "altitude";
DLLSPEC daeString COLLADA_ELEMENT_RENDERABLE = "renderable";
DLLSPEC daeString COLLADA_ELEMENT_INIT_FROM = "init_from";
DLLSPEC daeString COLLADA_ELEMENT_CREATE_2D = "create_2d";
DLLSPEC daeString COLLADA_ELEMENT_CREATE_3D = "create_3d";
DLLSPEC daeString COLLADA_ELEMENT_CREATE_CUBE = "create_cube";
DLLSPEC daeString COLLADA_ELEMENT_SIZE_EXACT = "size_exact";
DLLSPEC daeString COLLADA_ELEMENT_SIZE_RATIO = "size_ratio";
DLLSPEC daeString COLLADA_ELEMENT_MIPS = "mips";
DLLSPEC daeString COLLADA_ELEMENT_UNNORMALIZED = "unnormalized";
DLLSPEC daeString COLLADA_ELEMENT_ARRAY = "array";
DLLSPEC daeString COLLADA_ELEMENT_FORMAT = "format";
DLLSPEC daeString COLLADA_ELEMENT_HINT = "hint";
DLLSPEC daeString COLLADA_ELEMENT_EXACT = "exact";
DLLSPEC daeString COLLADA_ELEMENT_SIZE = "size";
DLLSPEC daeString COLLADA_ELEMENT_OPTICS = "optics";
DLLSPEC daeString COLLADA_ELEMENT_IMAGER = "imager";
DLLSPEC daeString COLLADA_ELEMENT_TECHNIQUE_COMMON = "technique_common";
DLLSPEC daeString COLLADA_ELEMENT_ORTHOGRAPHIC = "orthographic";
DLLSPEC daeString COLLADA_ELEMENT_PERSPECTIVE = "perspective";
DLLSPEC daeString COLLADA_ELEMENT_XMAG = "xmag";
DLLSPEC daeString COLLADA_ELEMENT_YMAG = "ymag";
DLLSPEC daeString COLLADA_ELEMENT_ASPECT_RATIO = "aspect_ratio";
DLLSPEC daeString COLLADA_ELEMENT_ZNEAR = "znear";
DLLSPEC daeString COLLADA_ELEMENT_ZFAR = "zfar";
DLLSPEC daeString COLLADA_ELEMENT_XFOV = "xfov";
DLLSPEC daeString COLLADA_ELEMENT_YFOV = "yfov";
DLLSPEC daeString COLLADA_ELEMENT_AMBIENT = "ambient";
DLLSPEC daeString COLLADA_ELEMENT_DIRECTIONAL = "directional";
DLLSPEC daeString COLLADA_ELEMENT_POINT = "point";
DLLSPEC daeString COLLADA_ELEMENT_SPOT = "spot";
DLLSPEC daeString COLLADA_ELEMENT_COLOR = "color";
DLLSPEC daeString COLLADA_ELEMENT_CONSTANT_ATTENUATION = "constant_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_LINEAR_ATTENUATION = "linear_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_QUADRATIC_ATTENUATION = "quadratic_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_FALLOFF_ANGLE = "falloff_angle";
DLLSPEC daeString COLLADA_ELEMENT_FALLOFF_EXPONENT = "falloff_exponent";
DLLSPEC daeString COLLADA_ELEMENT_BIND = "bind";
DLLSPEC daeString COLLADA_ELEMENT_BIND_VERTEX_INPUT = "bind_vertex_input";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_MATERIAL = "instance_material";
DLLSPEC daeString COLLADA_ELEMENT_SKELETON = "skeleton";
DLLSPEC daeString COLLADA_ELEMENT_BIND_MATERIAL = "bind_material";
DLLSPEC daeString COLLADA_ELEMENT_CAMERA = "camera";
DLLSPEC daeString COLLADA_ELEMENT_IMAGE = "image";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT = "light";
DLLSPEC daeString COLLADA_ELEMENT_TECHNIQUE_HINT = "technique_hint";
DLLSPEC daeString COLLADA_ELEMENT_SETPARAM = "setparam";
DLLSPEC daeString COLLADA_ELEMENT_FX_SETPARAM = "fx_setparam";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_EFFECT = "instance_effect";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL = "material";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_IMAGE = "instance_image";
DLLSPEC daeString COLLADA_ELEMENT_FX_SAMPLER_STATES = "fx_sampler_states";
DLLSPEC daeString COLLADA_ELEMENT_BOOL = "bool";
DLLSPEC daeString COLLADA_ELEMENT_BOOL2 = "bool2";
DLLSPEC daeString COLLADA_ELEMENT_BOOL3 = "bool3";
DLLSPEC daeString COLLADA_ELEMENT_BOOL4 = "bool4";
DLLSPEC daeString COLLADA_ELEMENT_INT = "int";
DLLSPEC daeString COLLADA_ELEMENT_INT2 = "int2";
DLLSPEC daeString COLLADA_ELEMENT_INT3 = "int3";
DLLSPEC daeString COLLADA_ELEMENT_INT4 = "int4";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT = "float";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT2 = "float2";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT3 = "float3";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT4 = "float4";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT2X2 = "float2x2";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT3X3 = "float3x3";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT4X4 = "float4x4";
DLLSPEC daeString COLLADA_ELEMENT_STRING = "string";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT2X1 = "float2x1";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT2X3 = "float2x3";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT2X4 = "float2x4";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT3X1 = "float3x1";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT3X2 = "float3x2";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT3X4 = "float3x4";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT4X1 = "float4x1";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT4X2 = "float4x2";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT4X3 = "float4x3";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER1D = "sampler1D";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER2D = "sampler2D";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER3D = "sampler3D";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLERCUBE = "samplerCUBE";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLERRECT = "samplerRECT";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLERDEPTH = "samplerDEPTH";
DLLSPEC daeString COLLADA_ELEMENT_ENUM = "enum";
DLLSPEC daeString COLLADA_ELEMENT_INLINE = "inline";
DLLSPEC daeString COLLADA_ELEMENT_IMPORT = "import";
DLLSPEC daeString COLLADA_ELEMENT_BINARY = "binary";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE = "texture";
DLLSPEC daeString COLLADA_ELEMENT_SEMANTIC = "semantic";
DLLSPEC daeString COLLADA_ELEMENT_NEWPARAM = "newparam";
DLLSPEC daeString COLLADA_ELEMENT_CONSTANT = "constant";
DLLSPEC daeString COLLADA_ELEMENT_LAMBERT = "lambert";
DLLSPEC daeString COLLADA_ELEMENT_PHONG = "phong";
DLLSPEC daeString COLLADA_ELEMENT_BLINN = "blinn";
DLLSPEC daeString COLLADA_ELEMENT_EMISSION = "emission";
DLLSPEC daeString COLLADA_ELEMENT_REFLECTIVE = "reflective";
DLLSPEC daeString COLLADA_ELEMENT_REFLECTIVITY = "reflectivity";
DLLSPEC daeString COLLADA_ELEMENT_TRANSPARENT = "transparent";
DLLSPEC daeString COLLADA_ELEMENT_TRANSPARENCY = "transparency";
DLLSPEC daeString COLLADA_ELEMENT_INDEX_OF_REFRACTION = "index_of_refraction";
DLLSPEC daeString COLLADA_ELEMENT_DIFFUSE = "diffuse";
DLLSPEC daeString COLLADA_ELEMENT_SPECULAR = "specular";
DLLSPEC daeString COLLADA_ELEMENT_SHININESS = "shininess";
DLLSPEC daeString COLLADA_ELEMENT_ANNOTATE = "annotate";
DLLSPEC daeString COLLADA_ELEMENT_MODIFIER = "modifier";
DLLSPEC daeString COLLADA_ELEMENT_GLES2_VALUE = "gles2_value";
DLLSPEC daeString COLLADA_ELEMENT_SOURCES = "sources";
DLLSPEC daeString COLLADA_ELEMENT_COMPILER = "compiler";
DLLSPEC daeString COLLADA_ELEMENT_SHADER = "shader";
DLLSPEC daeString COLLADA_ELEMENT_LINKER = "linker";
DLLSPEC daeString COLLADA_ELEMENT_BIND_ATTRIBUTE = "bind_attribute";
DLLSPEC daeString COLLADA_ELEMENT_BIND_UNIFORM = "bind_uniform";
DLLSPEC daeString COLLADA_ELEMENT_STATES = "states";
DLLSPEC daeString COLLADA_ELEMENT_PROGRAM = "program";
DLLSPEC daeString COLLADA_ELEMENT_EVALUATE = "evaluate";
DLLSPEC daeString COLLADA_ELEMENT_GLES2_PIPELINE_SETTINGS = "gles2_pipeline_settings";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_TARGET = "color_target";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_TARGET = "depth_target";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_TARGET = "stencil_target";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_CLEAR = "color_clear";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_CLEAR = "stencil_clear";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_CLEAR = "depth_clear";
DLLSPEC daeString COLLADA_ELEMENT_DRAW = "draw";
DLLSPEC daeString COLLADA_ELEMENT_INCLUDE = "include";
DLLSPEC daeString COLLADA_ELEMENT_CODE = "code";
DLLSPEC daeString COLLADA_ELEMENT_PASS = "pass";
DLLSPEC daeString COLLADA_ELEMENT_GLSL_VALUE = "glsl_value";
DLLSPEC daeString COLLADA_ELEMENT_GL_PIPELINE_SETTINGS = "gl_pipeline_settings";
DLLSPEC daeString COLLADA_ELEMENT_CG_PARAM = "cg_param";
DLLSPEC daeString COLLADA_ELEMENT_ARGUMENT = "argument";
DLLSPEC daeString COLLADA_ELEMENT_RGB = "RGB";
DLLSPEC daeString COLLADA_ELEMENT_ALPHA = "alpha";
DLLSPEC daeString COLLADA_ELEMENT_TEXCOMBINER = "texcombiner";
DLLSPEC daeString COLLADA_ELEMENT_TEXENV = "texenv";
DLLSPEC daeString COLLADA_ELEMENT_TEXCOORD = "texcoord";
DLLSPEC daeString COLLADA_ELEMENT_GLES_SAMPLER_STATES = "gles_sampler_states";
DLLSPEC daeString COLLADA_ELEMENT_GLES_PARAM = "gles_param";
DLLSPEC daeString COLLADA_ELEMENT_GLES_PIPELINE_SETTINGS = "gles_pipeline_settings";
DLLSPEC daeString COLLADA_ELEMENT_FX_PROFILE = "fx_profile";
DLLSPEC daeString COLLADA_ELEMENT_EFFECT = "effect";
DLLSPEC daeString COLLADA_ELEMENT_HALF_EXTENTS = "half_extents";
DLLSPEC daeString COLLADA_ELEMENT_EQUATION = "equation";
DLLSPEC daeString COLLADA_ELEMENT_RADIUS = "radius";
DLLSPEC daeString COLLADA_ELEMENT_HEIGHT = "height";
DLLSPEC daeString COLLADA_ELEMENT_FORCE_FIELD = "force_field";
DLLSPEC daeString COLLADA_ELEMENT_DYNAMIC_FRICTION = "dynamic_friction";
DLLSPEC daeString COLLADA_ELEMENT_RESTITUTION = "restitution";
DLLSPEC daeString COLLADA_ELEMENT_STATIC_FRICTION = "static_friction";
DLLSPEC daeString COLLADA_ELEMENT_PHYSICS_MATERIAL = "physics_material";
DLLSPEC daeString COLLADA_ELEMENT_ORIGIN = "origin";
DLLSPEC daeString COLLADA_ELEMENT_DIRECTION = "direction";
DLLSPEC daeString COLLADA_ELEMENT_FOCAL = "focal";
DLLSPEC daeString COLLADA_ELEMENT_TOKEN_ARRAY = "token_array";
DLLSPEC daeString COLLADA_ELEMENT_IDREF_ARRAY = "IDREF_array";
DLLSPEC daeString COLLADA_ELEMENT_NAME_ARRAY = "Name_array";
DLLSPEC daeString COLLADA_ELEMENT_BOOL_ARRAY = "bool_array";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT_ARRAY = "float_array";
DLLSPEC daeString COLLADA_ELEMENT_INT_ARRAY = "int_array";
DLLSPEC daeString COLLADA_ELEMENT_SIDREF_ARRAY = "SIDREF_array";
DLLSPEC daeString COLLADA_ELEMENT_ACCESSOR = "accessor";
DLLSPEC daeString COLLADA_ELEMENT_SOURCE = "source";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER = "sampler";
DLLSPEC daeString COLLADA_ELEMENT_CHANNEL = "channel";
DLLSPEC daeString COLLADA_ELEMENT_ANIMATION = "animation";
DLLSPEC daeString COLLADA_ELEMENT_BIND_SHAPE_MATRIX = "bind_shape_matrix";
DLLSPEC daeString COLLADA_ELEMENT_JOINTS = "joints";
DLLSPEC daeString COLLADA_ELEMENT_VERTEX_WEIGHTS = "vertex_weights";
DLLSPEC daeString COLLADA_ELEMENT_V = "v";
DLLSPEC daeString COLLADA_ELEMENT_VERTICES = "vertices";
DLLSPEC daeString COLLADA_ELEMENT_LINES = "lines";
DLLSPEC daeString COLLADA_ELEMENT_LINESTRIPS = "linestrips";
DLLSPEC daeString COLLADA_ELEMENT_POLYGONS = "polygons";
DLLSPEC daeString COLLADA_ELEMENT_POLYLIST = "polylist";
DLLSPEC daeString COLLADA_ELEMENT_TRIANGLES = "triangles";
DLLSPEC daeString COLLADA_ELEMENT_TRIFANS = "trifans";
DLLSPEC daeString COLLADA_ELEMENT_TRISTRIPS = "tristrips";
DLLSPEC daeString COLLADA_ELEMENT_CONTROL_VERTICES = "control_vertices";
DLLSPEC daeString COLLADA_ELEMENT_TARGETS = "targets";
DLLSPEC daeString COLLADA_ELEMENT_SKIN = "skin";
DLLSPEC daeString COLLADA_ELEMENT_MORPH = "morph";
DLLSPEC daeString COLLADA_ELEMENT_CONTROLLER = "controller";
DLLSPEC daeString COLLADA_ELEMENT_LINE = "line";
DLLSPEC daeString COLLADA_ELEMENT_CIRCLE = "circle";
DLLSPEC daeString COLLADA_ELEMENT_ELLIPSE = "ellipse";
DLLSPEC daeString COLLADA_ELEMENT_PARABOLA = "parabola";
DLLSPEC daeString COLLADA_ELEMENT_HYPERBOLA = "hyperbola";
DLLSPEC daeString COLLADA_ELEMENT_NURBS = "nurbs";
DLLSPEC daeString COLLADA_ELEMENT_ORIENT = "orient";
DLLSPEC daeString COLLADA_ELEMENT_CURVE = "curve";
DLLSPEC daeString COLLADA_ELEMENT_AXIS = "axis";
DLLSPEC daeString COLLADA_ELEMENT_ANGLE = "angle";
DLLSPEC daeString COLLADA_ELEMENT_PLANE = "plane";
DLLSPEC daeString COLLADA_ELEMENT_SPHERE = "sphere";
DLLSPEC daeString COLLADA_ELEMENT_TORUS = "torus";
DLLSPEC daeString COLLADA_ELEMENT_SWEPT_SURFACE = "swept_surface";
DLLSPEC daeString COLLADA_ELEMENT_NURBS_SURFACE = "nurbs_surface";
DLLSPEC daeString COLLADA_ELEMENT_CONE = "cone";
DLLSPEC daeString COLLADA_ELEMENT_CYLINDER = "cylinder";
DLLSPEC daeString COLLADA_ELEMENT_SURFACE = "surface";
DLLSPEC daeString COLLADA_ELEMENT_CURVES = "curves";
DLLSPEC daeString COLLADA_ELEMENT_SURFACE_CURVES = "surface_curves";
DLLSPEC daeString COLLADA_ELEMENT_SURFACES = "surfaces";
DLLSPEC daeString COLLADA_ELEMENT_EDGES = "edges";
DLLSPEC daeString COLLADA_ELEMENT_WIRES = "wires";
DLLSPEC daeString COLLADA_ELEMENT_FACES = "faces";
DLLSPEC daeString COLLADA_ELEMENT_PCURVES = "pcurves";
DLLSPEC daeString COLLADA_ELEMENT_SHELLS = "shells";
DLLSPEC daeString COLLADA_ELEMENT_SOLIDS = "solids";
DLLSPEC daeString COLLADA_ELEMENT_CONVEX_MESH = "convex_mesh";
DLLSPEC daeString COLLADA_ELEMENT_MESH = "mesh";
DLLSPEC daeString COLLADA_ELEMENT_SPLINE = "spline";
DLLSPEC daeString COLLADA_ELEMENT_BREP = "brep";
DLLSPEC daeString COLLADA_ELEMENT_GEOMETRY = "geometry";
DLLSPEC daeString COLLADA_ELEMENT_ROTATE = "rotate";
DLLSPEC daeString COLLADA_ELEMENT_TRANSLATE = "translate";
DLLSPEC daeString COLLADA_ELEMENT_ATTACHMENT_FULL = "attachment_full";
DLLSPEC daeString COLLADA_ELEMENT_ATTACHMENT_START = "attachment_start";
DLLSPEC daeString COLLADA_ELEMENT_ATTACHMENT_END = "attachment_end";
DLLSPEC daeString COLLADA_ELEMENT_LINK = "link";
DLLSPEC daeString COLLADA_ELEMENT_REF_ATTACHMENT = "ref_attachment";
DLLSPEC daeString COLLADA_ELEMENT_ATTACHMENT = "attachment";
DLLSPEC daeString COLLADA_ELEMENT_ENABLED = "enabled";
DLLSPEC daeString COLLADA_ELEMENT_INTERPENETRATE = "interpenetrate";
DLLSPEC daeString COLLADA_ELEMENT_LIMITS = "limits";
DLLSPEC daeString COLLADA_ELEMENT_SPRING = "spring";
DLLSPEC daeString COLLADA_ELEMENT_SWING_CONE_AND_TWIST = "swing_cone_and_twist";
DLLSPEC daeString COLLADA_ELEMENT_LINEAR = "linear";
DLLSPEC daeString COLLADA_ELEMENT_MIN = "min";
DLLSPEC daeString COLLADA_ELEMENT_MAX = "max";
DLLSPEC daeString COLLADA_ELEMENT_ANGULAR = "angular";
DLLSPEC daeString COLLADA_ELEMENT_STIFFNESS = "stiffness";
DLLSPEC daeString COLLADA_ELEMENT_DAMPING = "damping";
DLLSPEC daeString COLLADA_ELEMENT_TARGET_VALUE = "target_value";
DLLSPEC daeString COLLADA_ELEMENT_LOOKAT = "lookat";
DLLSPEC daeString COLLADA_ELEMENT_MATRIX = "matrix";
DLLSPEC daeString COLLADA_ELEMENT_SCALE = "scale";
DLLSPEC daeString COLLADA_ELEMENT_SKEW = "skew";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_CAMERA = "instance_camera";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_CONTROLLER = "instance_controller";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_GEOMETRY = "instance_geometry";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_LIGHT = "instance_light";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_NODE = "instance_node";
DLLSPEC daeString COLLADA_ELEMENT_NODE = "node";
DLLSPEC daeString COLLADA_ELEMENT_EVALUATE_SCENE = "evaluate_scene";
DLLSPEC daeString COLLADA_ELEMENT_RENDER = "render";
DLLSPEC daeString COLLADA_ELEMENT_LAYER = "layer";
DLLSPEC daeString COLLADA_ELEMENT_TECHNIQUE_OVERRIDE = "technique_override";
DLLSPEC daeString COLLADA_ELEMENT_VISUAL_SCENE = "visual_scene";
DLLSPEC daeString COLLADA_ELEMENT_DYNAMIC = "dynamic";
DLLSPEC daeString COLLADA_ELEMENT_MASS = "mass";
DLLSPEC daeString COLLADA_ELEMENT_MASS_FRAME = "mass_frame";
DLLSPEC daeString COLLADA_ELEMENT_INERTIA = "inertia";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_PHYSICS_MATERIAL = "instance_physics_material";
DLLSPEC daeString COLLADA_ELEMENT_SHAPE = "shape";
DLLSPEC daeString COLLADA_ELEMENT_HOLLOW = "hollow";
DLLSPEC daeString COLLADA_ELEMENT_DENSITY = "density";
DLLSPEC daeString COLLADA_ELEMENT_BOX = "box";
DLLSPEC daeString COLLADA_ELEMENT_CAPSULE = "capsule";
DLLSPEC daeString COLLADA_ELEMENT_ANGULAR_VELOCITY = "angular_velocity";
DLLSPEC daeString COLLADA_ELEMENT_VELOCITY = "velocity";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_FORCE_FIELD = "instance_force_field";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_RIGID_BODY = "instance_rigid_body";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_RIGID_CONSTRAINT = "instance_rigid_constraint";
DLLSPEC daeString COLLADA_ELEMENT_RIGID_BODY = "rigid_body";
DLLSPEC daeString COLLADA_ELEMENT_RIGID_CONSTRAINT = "rigid_constraint";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_PHYSICS_MODEL = "instance_physics_model";
DLLSPEC daeString COLLADA_ELEMENT_PHYSICS_MODEL = "physics_model";
DLLSPEC daeString COLLADA_ELEMENT_GRAVITY = "gravity";
DLLSPEC daeString COLLADA_ELEMENT_TIME_STEP = "time_step";
DLLSPEC daeString COLLADA_ELEMENT_PHYSICS_SCENE = "physics_scene";
DLLSPEC daeString COLLADA_ELEMENT_SIDREF = "SIDREF";
DLLSPEC daeString COLLADA_ELEMENT_VALUE = "value";
DLLSPEC daeString COLLADA_ELEMENT_CONNECT_PARAM = "connect_param";
DLLSPEC daeString COLLADA_ELEMENT_BIND_KINEMATICS_MODEL = "bind_kinematics_model";
DLLSPEC daeString COLLADA_ELEMENT_BIND_JOINT_AXIS = "bind_joint_axis";
DLLSPEC daeString COLLADA_ELEMENT_SPEED = "speed";
DLLSPEC daeString COLLADA_ELEMENT_ACCELERATION = "acceleration";
DLLSPEC daeString COLLADA_ELEMENT_DECELERATION = "deceleration";
DLLSPEC daeString COLLADA_ELEMENT_JERK = "jerk";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_KINEMATICS_MODEL = "instance_kinematics_model";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_ARTICULATED_SYSTEM = "instance_articulated_system";
DLLSPEC daeString COLLADA_ELEMENT_KINEMATICS_SCENE = "kinematics_scene";
DLLSPEC daeString COLLADA_ELEMENT_AXIS_INFO = "axis_info";
DLLSPEC daeString COLLADA_ELEMENT_EFFECTOR_INFO = "effector_info";
DLLSPEC daeString COLLADA_ELEMENT_PRISMATIC = "prismatic";
DLLSPEC daeString COLLADA_ELEMENT_REVOLUTE = "revolute";
DLLSPEC daeString COLLADA_ELEMENT_JOINT = "joint";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_ANIMATION = "instance_animation";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_FORMULA = "instance_formula";
DLLSPEC daeString COLLADA_ELEMENT_ANIMATION_CLIP = "animation_clip";
DLLSPEC daeString COLLADA_ELEMENT_TARGET = "target";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_JOINT = "instance_joint";
DLLSPEC daeString COLLADA_ELEMENT_FORMULA = "formula";
DLLSPEC daeString COLLADA_ELEMENT_KINEMATICS_MODEL = "kinematics_model";
DLLSPEC daeString COLLADA_ELEMENT_ACTIVE = "active";
DLLSPEC daeString COLLADA_ELEMENT_LOCKED = "locked";
DLLSPEC daeString COLLADA_ELEMENT_INDEX = "index";
DLLSPEC daeString COLLADA_ELEMENT_FRAME_ORIGIN = "frame_origin";
DLLSPEC daeString COLLADA_ELEMENT_FRAME_TIP = "frame_tip";
DLLSPEC daeString COLLADA_ELEMENT_FRAME_TCP = "frame_tcp";
DLLSPEC daeString COLLADA_ELEMENT_FRAME_OBJECT = "frame_object";
DLLSPEC daeString COLLADA_ELEMENT_KINEMATICS = "kinematics";
DLLSPEC daeString COLLADA_ELEMENT_MOTION = "motion";
DLLSPEC daeString COLLADA_ELEMENT_ARTICULATED_SYSTEM = "articulated_system";
DLLSPEC daeString COLLADA_ELEMENT_WRAP_S = "wrap_s";
DLLSPEC daeString COLLADA_ELEMENT_WRAP_T = "wrap_t";
DLLSPEC daeString COLLADA_ELEMENT_WRAP_P = "wrap_p";
DLLSPEC daeString COLLADA_ELEMENT_MINFILTER = "minfilter";
DLLSPEC daeString COLLADA_ELEMENT_MAGFILTER = "magfilter";
DLLSPEC daeString COLLADA_ELEMENT_MIPFILTER = "mipfilter";
DLLSPEC daeString COLLADA_ELEMENT_BORDER_COLOR = "border_color";
DLLSPEC daeString COLLADA_ELEMENT_MIP_MAX_LEVEL = "mip_max_level";
DLLSPEC daeString COLLADA_ELEMENT_MIP_MIN_LEVEL = "mip_min_level";
DLLSPEC daeString COLLADA_ELEMENT_MIP_BIAS = "mip_bias";
DLLSPEC daeString COLLADA_ELEMENT_MAX_ANISOTROPY = "max_anisotropy";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER_IMAGE = "sampler_image";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLER_STATES = "sampler_states";
DLLSPEC daeString COLLADA_ELEMENT_ALPHA_FUNC = "alpha_func";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_FUNC = "blend_func";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_FUNC_SEPARATE = "blend_func_separate";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_EQUATION = "blend_equation";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_EQUATION_SEPARATE = "blend_equation_separate";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_MATERIAL = "color_material";
DLLSPEC daeString COLLADA_ELEMENT_CULL_FACE = "cull_face";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_FUNC = "depth_func";
DLLSPEC daeString COLLADA_ELEMENT_FOG_MODE = "fog_mode";
DLLSPEC daeString COLLADA_ELEMENT_FOG_COORD_SRC = "fog_coord_src";
DLLSPEC daeString COLLADA_ELEMENT_FRONT_FACE = "front_face";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_MODEL_COLOR_CONTROL = "light_model_color_control";
DLLSPEC daeString COLLADA_ELEMENT_LOGIC_OP = "logic_op";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_MODE = "polygon_mode";
DLLSPEC daeString COLLADA_ELEMENT_SHADE_MODEL = "shade_model";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_FUNC = "stencil_func";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_OP = "stencil_op";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_FUNC_SEPARATE = "stencil_func_separate";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_OP_SEPARATE = "stencil_op_separate";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_MASK_SEPARATE = "stencil_mask_separate";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_ENABLE = "light_enable";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_AMBIENT = "light_ambient";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_DIFFUSE = "light_diffuse";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_SPECULAR = "light_specular";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_POSITION = "light_position";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_CONSTANT_ATTENUATION = "light_constant_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_LINEAR_ATTENUATION = "light_linear_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_QUADRATIC_ATTENUATION = "light_quadratic_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_SPOT_CUTOFF = "light_spot_cutoff";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_SPOT_DIRECTION = "light_spot_direction";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_SPOT_EXPONENT = "light_spot_exponent";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE1D = "texture1D";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE2D = "texture2D";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE3D = "texture3D";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURECUBE = "textureCUBE";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURERECT = "textureRECT";
DLLSPEC daeString COLLADA_ELEMENT_TEXTUREDEPTH = "textureDEPTH";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE1D_ENABLE = "texture1D_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE2D_ENABLE = "texture2D_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE3D_ENABLE = "texture3D_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURECUBE_ENABLE = "textureCUBE_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURERECT_ENABLE = "textureRECT_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTUREDEPTH_ENABLE = "textureDEPTH_enable";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE_ENV_COLOR = "texture_env_color";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE_ENV_MODE = "texture_env_mode";
DLLSPEC daeString COLLADA_ELEMENT_CLIP_PLANE = "clip_plane";
DLLSPEC daeString COLLADA_ELEMENT_CLIP_PLANE_ENABLE = "clip_plane_enable";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_COLOR = "blend_color";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_MASK = "color_mask";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_BOUNDS = "depth_bounds";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_MASK = "depth_mask";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_RANGE = "depth_range";
DLLSPEC daeString COLLADA_ELEMENT_FOG_DENSITY = "fog_density";
DLLSPEC daeString COLLADA_ELEMENT_FOG_START = "fog_start";
DLLSPEC daeString COLLADA_ELEMENT_FOG_END = "fog_end";
DLLSPEC daeString COLLADA_ELEMENT_FOG_COLOR = "fog_color";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_MODEL_AMBIENT = "light_model_ambient";
DLLSPEC daeString COLLADA_ELEMENT_LIGHTING_ENABLE = "lighting_enable";
DLLSPEC daeString COLLADA_ELEMENT_LINE_STIPPLE = "line_stipple";
DLLSPEC daeString COLLADA_ELEMENT_LINE_WIDTH = "line_width";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL_AMBIENT = "material_ambient";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL_DIFFUSE = "material_diffuse";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL_EMISSION = "material_emission";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL_SHININESS = "material_shininess";
DLLSPEC daeString COLLADA_ELEMENT_MATERIAL_SPECULAR = "material_specular";
DLLSPEC daeString COLLADA_ELEMENT_MODEL_VIEW_MATRIX = "model_view_matrix";
DLLSPEC daeString COLLADA_ELEMENT_POINT_DISTANCE_ATTENUATION = "point_distance_attenuation";
DLLSPEC daeString COLLADA_ELEMENT_POINT_FADE_THRESHOLD_SIZE = "point_fade_threshold_size";
DLLSPEC daeString COLLADA_ELEMENT_POINT_SIZE = "point_size";
DLLSPEC daeString COLLADA_ELEMENT_POINT_SIZE_MIN = "point_size_min";
DLLSPEC daeString COLLADA_ELEMENT_POINT_SIZE_MAX = "point_size_max";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_OFFSET = "polygon_offset";
DLLSPEC daeString COLLADA_ELEMENT_PROJECTION_MATRIX = "projection_matrix";
DLLSPEC daeString COLLADA_ELEMENT_SCISSOR = "scissor";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_MASK = "stencil_mask";
DLLSPEC daeString COLLADA_ELEMENT_ALPHA_TEST_ENABLE = "alpha_test_enable";
DLLSPEC daeString COLLADA_ELEMENT_BLEND_ENABLE = "blend_enable";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_LOGIC_OP_ENABLE = "color_logic_op_enable";
DLLSPEC daeString COLLADA_ELEMENT_COLOR_MATERIAL_ENABLE = "color_material_enable";
DLLSPEC daeString COLLADA_ELEMENT_CULL_FACE_ENABLE = "cull_face_enable";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_BOUNDS_ENABLE = "depth_bounds_enable";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_CLAMP_ENABLE = "depth_clamp_enable";
DLLSPEC daeString COLLADA_ELEMENT_DEPTH_TEST_ENABLE = "depth_test_enable";
DLLSPEC daeString COLLADA_ELEMENT_DITHER_ENABLE = "dither_enable";
DLLSPEC daeString COLLADA_ELEMENT_FOG_ENABLE = "fog_enable";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_MODEL_LOCAL_VIEWER_ENABLE = "light_model_local_viewer_enable";
DLLSPEC daeString COLLADA_ELEMENT_LIGHT_MODEL_TWO_SIDE_ENABLE = "light_model_two_side_enable";
DLLSPEC daeString COLLADA_ELEMENT_LINE_SMOOTH_ENABLE = "line_smooth_enable";
DLLSPEC daeString COLLADA_ELEMENT_LINE_STIPPLE_ENABLE = "line_stipple_enable";
DLLSPEC daeString COLLADA_ELEMENT_LOGIC_OP_ENABLE = "logic_op_enable";
DLLSPEC daeString COLLADA_ELEMENT_MULTISAMPLE_ENABLE = "multisample_enable";
DLLSPEC daeString COLLADA_ELEMENT_NORMALIZE_ENABLE = "normalize_enable";
DLLSPEC daeString COLLADA_ELEMENT_POINT_SMOOTH_ENABLE = "point_smooth_enable";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_OFFSET_FILL_ENABLE = "polygon_offset_fill_enable";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_OFFSET_LINE_ENABLE = "polygon_offset_line_enable";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_OFFSET_POINT_ENABLE = "polygon_offset_point_enable";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_SMOOTH_ENABLE = "polygon_smooth_enable";
DLLSPEC daeString COLLADA_ELEMENT_POLYGON_STIPPLE_ENABLE = "polygon_stipple_enable";
DLLSPEC daeString COLLADA_ELEMENT_RESCALE_NORMAL_ENABLE = "rescale_normal_enable";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLE_ALPHA_TO_COVERAGE_ENABLE = "sample_alpha_to_coverage_enable";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLE_ALPHA_TO_ONE_ENABLE = "sample_alpha_to_one_enable";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLE_COVERAGE_ENABLE = "sample_coverage_enable";
DLLSPEC daeString COLLADA_ELEMENT_SCISSOR_TEST_ENABLE = "scissor_test_enable";
DLLSPEC daeString COLLADA_ELEMENT_STENCIL_TEST_ENABLE = "stencil_test_enable";
DLLSPEC daeString COLLADA_ELEMENT_FUNC = "func";
DLLSPEC daeString COLLADA_ELEMENT_SRC = "src";
DLLSPEC daeString COLLADA_ELEMENT_DEST = "dest";
DLLSPEC daeString COLLADA_ELEMENT_SRC_RGB = "src_rgb";
DLLSPEC daeString COLLADA_ELEMENT_DEST_RGB = "dest_rgb";
DLLSPEC daeString COLLADA_ELEMENT_SRC_ALPHA = "src_alpha";
DLLSPEC daeString COLLADA_ELEMENT_DEST_ALPHA = "dest_alpha";
DLLSPEC daeString COLLADA_ELEMENT_rgb = "rgb";
DLLSPEC daeString COLLADA_ELEMENT_FACE = "face";
DLLSPEC daeString COLLADA_ELEMENT_MODE = "mode";
DLLSPEC daeString COLLADA_ELEMENT_MASK = "mask";
DLLSPEC daeString COLLADA_ELEMENT_FAIL = "fail";
DLLSPEC daeString COLLADA_ELEMENT_ZFAIL = "zfail";
DLLSPEC daeString COLLADA_ELEMENT_ZPASS = "zpass";
DLLSPEC daeString COLLADA_ELEMENT_FRONT = "front";
DLLSPEC daeString COLLADA_ELEMENT_BACK = "back";
DLLSPEC daeString COLLADA_ELEMENT_SAMPLE_COVERAGE = "sample_coverage";
DLLSPEC daeString COLLADA_ELEMENT_POINT_SIZE_ENABLE = "point_size_enable";
DLLSPEC daeString COLLADA_ELEMENT_INVERT = "invert";
DLLSPEC daeString COLLADA_ELEMENT_BVEC2 = "bvec2";
DLLSPEC daeString COLLADA_ELEMENT_BVEC3 = "bvec3";
DLLSPEC daeString COLLADA_ELEMENT_BVEC4 = "bvec4";
DLLSPEC daeString COLLADA_ELEMENT_VEC2 = "vec2";
DLLSPEC daeString COLLADA_ELEMENT_VEC3 = "vec3";
DLLSPEC daeString COLLADA_ELEMENT_VEC4 = "vec4";
DLLSPEC daeString COLLADA_ELEMENT_MAT2 = "mat2";
DLLSPEC daeString COLLADA_ELEMENT_MAT3 = "mat3";
DLLSPEC daeString COLLADA_ELEMENT_MAT4 = "mat4";
DLLSPEC daeString COLLADA_ELEMENT_IVEC2 = "ivec2";
DLLSPEC daeString COLLADA_ELEMENT_IVEC3 = "ivec3";
DLLSPEC daeString COLLADA_ELEMENT_IVEC4 = "ivec4";
DLLSPEC daeString COLLADA_ELEMENT_USERTYPE = "usertype";
DLLSPEC daeString COLLADA_ELEMENT_BOOL2X1 = "bool2x1";
DLLSPEC daeString COLLADA_ELEMENT_BOOL2X2 = "bool2x2";
DLLSPEC daeString COLLADA_ELEMENT_BOOL2X3 = "bool2x3";
DLLSPEC daeString COLLADA_ELEMENT_BOOL2X4 = "bool2x4";
DLLSPEC daeString COLLADA_ELEMENT_BOOL3X1 = "bool3x1";
DLLSPEC daeString COLLADA_ELEMENT_BOOL3X2 = "bool3x2";
DLLSPEC daeString COLLADA_ELEMENT_BOOL3X3 = "bool3x3";
DLLSPEC daeString COLLADA_ELEMENT_BOOL3X4 = "bool3x4";
DLLSPEC daeString COLLADA_ELEMENT_BOOL4X1 = "bool4x1";
DLLSPEC daeString COLLADA_ELEMENT_BOOL4X2 = "bool4x2";
DLLSPEC daeString COLLADA_ELEMENT_BOOL4X3 = "bool4x3";
DLLSPEC daeString COLLADA_ELEMENT_BOOL4X4 = "bool4x4";
DLLSPEC daeString COLLADA_ELEMENT_INT2X1 = "int2x1";
DLLSPEC daeString COLLADA_ELEMENT_INT2X2 = "int2x2";
DLLSPEC daeString COLLADA_ELEMENT_INT2X3 = "int2x3";
DLLSPEC daeString COLLADA_ELEMENT_INT2X4 = "int2x4";
DLLSPEC daeString COLLADA_ELEMENT_INT3X1 = "int3x1";
DLLSPEC daeString COLLADA_ELEMENT_INT3X2 = "int3x2";
DLLSPEC daeString COLLADA_ELEMENT_INT3X3 = "int3x3";
DLLSPEC daeString COLLADA_ELEMENT_INT3X4 = "int3x4";
DLLSPEC daeString COLLADA_ELEMENT_INT4X1 = "int4x1";
DLLSPEC daeString COLLADA_ELEMENT_INT4X2 = "int4x2";
DLLSPEC daeString COLLADA_ELEMENT_INT4X3 = "int4x3";
DLLSPEC daeString COLLADA_ELEMENT_INT4X4 = "int4x4";
DLLSPEC daeString COLLADA_ELEMENT_HALF = "half";
DLLSPEC daeString COLLADA_ELEMENT_HALF2 = "half2";
DLLSPEC daeString COLLADA_ELEMENT_HALF3 = "half3";
DLLSPEC daeString COLLADA_ELEMENT_HALF4 = "half4";
DLLSPEC daeString COLLADA_ELEMENT_HALF2X1 = "half2x1";
DLLSPEC daeString COLLADA_ELEMENT_HALF2X2 = "half2x2";
DLLSPEC daeString COLLADA_ELEMENT_HALF2X3 = "half2x3";
DLLSPEC daeString COLLADA_ELEMENT_HALF2X4 = "half2x4";
DLLSPEC daeString COLLADA_ELEMENT_HALF3X1 = "half3x1";
DLLSPEC daeString COLLADA_ELEMENT_HALF3X2 = "half3x2";
DLLSPEC daeString COLLADA_ELEMENT_HALF3X3 = "half3x3";
DLLSPEC daeString COLLADA_ELEMENT_HALF3X4 = "half3x4";
DLLSPEC daeString COLLADA_ELEMENT_HALF4X1 = "half4x1";
DLLSPEC daeString COLLADA_ELEMENT_HALF4X2 = "half4x2";
DLLSPEC daeString COLLADA_ELEMENT_HALF4X3 = "half4x3";
DLLSPEC daeString COLLADA_ELEMENT_HALF4X4 = "half4x4";
DLLSPEC daeString COLLADA_ELEMENT_FIXED = "fixed";
DLLSPEC daeString COLLADA_ELEMENT_FIXED2 = "fixed2";
DLLSPEC daeString COLLADA_ELEMENT_FIXED3 = "fixed3";
DLLSPEC daeString COLLADA_ELEMENT_FIXED4 = "fixed4";
DLLSPEC daeString COLLADA_ELEMENT_FIXED2X1 = "fixed2x1";
DLLSPEC daeString COLLADA_ELEMENT_FIXED2X2 = "fixed2x2";
DLLSPEC daeString COLLADA_ELEMENT_FIXED2X3 = "fixed2x3";
DLLSPEC daeString COLLADA_ELEMENT_FIXED2X4 = "fixed2x4";
DLLSPEC daeString COLLADA_ELEMENT_FIXED3X1 = "fixed3x1";
DLLSPEC daeString COLLADA_ELEMENT_FIXED3X2 = "fixed3x2";
DLLSPEC daeString COLLADA_ELEMENT_FIXED3X3 = "fixed3x3";
DLLSPEC daeString COLLADA_ELEMENT_FIXED3X4 = "fixed3x4";
DLLSPEC daeString COLLADA_ELEMENT_FIXED4X1 = "fixed4x1";
DLLSPEC daeString COLLADA_ELEMENT_FIXED4X2 = "fixed4x2";
DLLSPEC daeString COLLADA_ELEMENT_FIXED4X3 = "fixed4x3";
DLLSPEC daeString COLLADA_ELEMENT_FIXED4X4 = "fixed4x4";
DLLSPEC daeString COLLADA_ELEMENT_TEXTURE_PIPELINE = "texture_pipeline";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT1X1 = "float1x1";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT1X2 = "float1x2";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT1X3 = "float1x3";
DLLSPEC daeString COLLADA_ELEMENT_FLOAT1X4 = "float1x4";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_COMMON = "profile_COMMON";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_BRIDGE = "profile_BRIDGE";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_GLES2 = "profile_GLES2";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_GLSL = "profile_GLSL";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_CG = "profile_CG";
DLLSPEC daeString COLLADA_ELEMENT_PROFILE_GLES = "profile_GLES";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_ANIMATIONS = "library_animations";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_ANIMATION_CLIPS = "library_animation_clips";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_CAMERAS = "library_cameras";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_CONTROLLERS = "library_controllers";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_GEOMETRIES = "library_geometries";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_EFFECTS = "library_effects";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_FORCE_FIELDS = "library_force_fields";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_IMAGES = "library_images";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_LIGHTS = "library_lights";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_MATERIALS = "library_materials";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_NODES = "library_nodes";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_PHYSICS_MATERIALS = "library_physics_materials";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_PHYSICS_MODELS = "library_physics_models";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_PHYSICS_SCENES = "library_physics_scenes";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_VISUAL_SCENES = "library_visual_scenes";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_JOINTS = "library_joints";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_KINEMATICS_MODELS = "library_kinematics_models";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_ARTICULATED_SYSTEMS = "library_articulated_systems";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_KINEMATICS_SCENES = "library_kinematics_scenes";
DLLSPEC daeString COLLADA_ELEMENT_LIBRARY_FORMULAS = "library_formulas";
DLLSPEC daeString COLLADA_ELEMENT_SCENE = "scene";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_PHYSICS_SCENE = "instance_physics_scene";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_VISUAL_SCENE = "instance_visual_scene";
DLLSPEC daeString COLLADA_ELEMENT_INSTANCE_KINEMATICS_SCENE = "instance_kinematics_scene";

} // ColladaDOM150
